Skip to main content

squaddata

Create datasets and reports from squad

Installation

Use pip to install from gitlab

pip install https://gitlab.com/Linaro/lkft/reports/squaddata/-/archive/master/squaddata-master.tar.gz

Examples

Create a report from a squad project

squad_report --group=lkft --project=linux-next-master --build=next-20210223 full

Create a report that shows build results for all environments

squad_report --group=lkft --project=linux-next-master --build=next-20210223 --suites=build full

Create a report that shows build results for the arm64 environment

squad_report --group=lkft --project=linux-next-master --build=next-20210223 --suites=build --environments=arm64 full

Create a report that shows kselftest results

squad_report --group=lkft --project=linux-next-master --build=next-20210223 --suite-prefixes=kselftest full

Usage

usage: squad_report [-h] [--url URL] [--token TOKEN]
       [--group GROUP] [--project PROJECT] [--build BUILD] [--base-build BASE_BUILD]
       [--environments ENVIRONMENTS | --environment-prefixes ENVIRONMENT_PREFIXES]
       [--output OUTPUT]
       [--suites SUITES | --suite-prefixes SUITE_PREFIXES]
       [--template TEMPLATE]
       [--unfinished]

Create a report using data from SQUAD

positional arguments:
  report                Type of report to create

optional arguments:
  -h, --help            show this help message and exit
  --url URL             URL of the SQUAD service
  --token TOKEN         Authentication token of the SQUAD service
  --group GROUP         SQUAD group
  --project PROJECT     SQUAD project
  --build BUILD         SQUAD build
  --base-build BASE_BUILD
                        SQUAD build to compare to
  --environments ENVIRONMENTS
                        List of SQUAD environments to include
  --environment-prefixes ENVIRONMENT_PREFIXES
                        List of prefixes of SQUAD environments to include
  --output OUTPUT       Write the output to this file
  --suites SUITES       List of SQUAD suites to include
  --suite-prefixes SUITE_PREFIXES
                        List of prefixes of SQUAD suites to include
  --template TEMPLATE   Create the report with this template. Default=report
  --unfinished          Compare with a build that has not finished

Debugging

To turn on debug output, set LOG_LEVEL=DEBUG in the environment.

Contributing

CONTRIBUTING.md

License

MIT

Metadata

Release files for squaddata 0.0.2

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for squaddata 0.0.2
File Size Uploaded
squaddata-0.0.2.tar.gz 8.2 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for squaddata 0.0.2
File Interpreter ABI Platform
squaddata-0.0.2-py3-none-any.whl Python 3 none any Details

Total release size: 17.0 kB

Release files / squaddata-0.0.2.tar.gz

Download URL squaddata-0.0.2.tar.gz
Size 8.2 kB
Tags Source
SHA-256 checksum
How to use checksums
ec29bd886452c6622dd558bc23ec4e51646c913e6d080d42f33e0c5be51e3393
BLAKE2b-256 checksum
How to use checksums
8ac59d29b1e38c7b7c29d53e23ec36f643dc70ad237937487eb1d0a06ee4ef34
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/3.4.1 importlib_metadata/3.7.3 pkginfo/1.7.0 requests/2.25.1 requests-toolbelt/0.9.1 tqdm/4.56.0 CPython/3.9.2

Release files / squaddata-0.0.2-py3-none-any.whl

Download URL squaddata-0.0.2-py3-none-any.whl
Size 8.8 kB
Tags Python 3
SHA-256 checksum
How to use checksums
0b043e12918082d1af9313b16f472d0a48181f43b4e6d5bbf892f199d042b1ab
BLAKE2b-256 checksum
How to use checksums
c6b7bebb254cfc17446e772c79b99bbceef512730114688b20da7fd18b796076
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/3.4.1 importlib_metadata/3.7.3 pkginfo/1.7.0 requests/2.25.1 requests-toolbelt/0.9.1 tqdm/4.56.0 CPython/3.9.2

Release history Release notifications | RSS feed

This release

0.0.2 This release

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page